/*
* forward declaration of rds2cif driver functions
*/
extern void savecif();

#ifdef DRIVECIF_C
static char *busname();
static void drive_model();
static long getcifmodel();
static void wr_con();
static void wr_figure();
static void wr_header();
static void wr_ins();
static void wr_model_header();
static void wr_model_tail();
static void wr_rect();
static void wr_tail();
#undef DRIVECIF_C
#endif
